@@ -13,6 +13,7 @@ class BitmexClient:
     def __init__(self, api_key=None, api_secret=None, testnet=True):
         self.client = bitmex.bitmex(
             api_key=api_key, api_secret=api_secret, test=testnet)
+        self._last_wallet_balance = ''
         self._last_currentprice = {}
         self.testnet = testnet
 
@@ -20,7 +21,12 @@ class BitmexClient:
         return self.client
 
     def get_wallet(self, prop):
-        return self.client.User.User_getWallet().result()[0][str(prop)]
+        try:
+            wallet_balance = self.client.User.User_getWallet().result()[0][str(prop)]
+            self._last_wallet_balance = wallet_balance
+            return wallet_balance
+        except HTTPBadRequest:
+            return self._last_wallet_balance
 
     def get_position(self, symbol, prop):
         try:
@@ -182,14 +188,14 @@ class BitmexOrder:
             elif self.props[symbol]['open']:
                 if self.props[symbol]['qty'] > 0 and cp <= self.props[symbol]['SL'] and self.client.open_contracts(symbol) == 0:
                     self.props[symbol]['open'] = False
-                    self.props[symbol]['qty'] = 0
                     print("Long Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
-                                                                                                          self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
+                                                                                                          self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, self.props[symbol]['SL']-self.props[symbol]['entry'])), flush=True)
+                    self.props[symbol]['qty'] = 0
                 elif self.props[symbol]['qty'] < 0 and cp >= self.props[symbol]['SL'] and self.client.open_contracts(symbol) == 0:
                     self.props[symbol]['open'] = False
-                    self.props[symbol]['qty'] = 0
                     print("Short Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
-                                                                                                           -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
+                                                                                                           -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, self.props[symbol]['entry']-self.props[symbol]['SL'])), flush=True)
+                    self.props[symbol]['qty'] = 0
 
     def generate_id(self, symbol, _type='stop'):
         return "{}_{}_{}_{}".format(self.magic, symbol, str(uuid.uuid4().fields[-1])[:5], _type)
@@ -273,7 +279,7 @@ class BitmexOrder:
             print("Error placing bracket stop order in {}.".format(
                 symbol), e, flush=True)
 
-    def bracket_market_order(self, symbol, orderQty, sl, tp=0):
+    def bracket_market_order(self, symbol, orderQty, sl, cp, tp=0):
         try:
             entry = self.market_order(symbol, orderQty)
             self.props[symbol]['SL'] = sl
@@ -281,6 +287,7 @@ class BitmexOrder:
             time.sleep(5)
             stoploss = self.stoploss_order(symbol)
             self.props[symbol]['qty'] = orderQty
+            self.props[symbol]['entry'] = cp
             return entry, stoploss
         except HTTPBadRequest as e:
             print("Error placing bracket market order in {}.".format(
