@@ -88,14 +88,14 @@ class Lotus:
 
     def process_signals(self, ns, start=False):
         for symbol in self.symbols:
-            entry = ns[symbol]['entry']
-            stoploss = ns[symbol]['stoploss']
             if start:
                 self.order.check_open_bot_order(symbol, entry, stoploss)
                 time.sleep(3)
-            if self.is_new_signal_symbol(ns, symbol):
-                signal = ns[symbol]['signal']
-                if signal:
+            signal = ns[symbol]['signal']
+            if signal:
+                if self.is_new_signal_symbol(ns, symbol):
+                    entry = ns[symbol]['entry']
+                    stoploss = ns[symbol]['stoploss']
                     if signal in [-1, 1]:  # signal has open position
                         if signal == 1:
                             if self.order.props[symbol]['qty'] > 0 or self.client.open_contracts(symbol) > 0:
@@ -167,9 +167,9 @@ class Lotus:
                     else:
                         if self.order.props[symbol]['open']:
                             self.order.close(symbol)
-                else:
-                    self.manage_open_stop_orders(symbol)
-                    print("This signal is only for members.", flush=True)
+            else:
+                self.manage_open_stop_orders(symbol)
+                print("This signal in {} is only for members.".format(symbol), flush=True)
 
     def run(self):
         # Main loop
